@@ -7,16 +7,14 @@ use warnings;
 use attributes ();
 use Carp       ();
 
-use UNIVERSAL::Object::Immutable;
-
 use MOP::Method::Attribute;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.13';
+our $VERSION   = '0.14';
 our $AUTHORITY = 'cpan:STEVAN';
 
-our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object::Immutable' };
+use parent 'UNIVERSAL::Object::Immutable';
 
 sub BUILDARGS {
     my $class = shift;
@@ -128,7 +126,7 @@ MOP::Method - A representation of a method
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
@@ -171,7 +169,7 @@ Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Stevan Little.
+This software is copyright (c) 2017, 2018 by Stevan Little.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
