@@ -6,12 +6,11 @@ use warnings;
 
 use Carp ();
 
-use UNIVERSAL::Object::Immutable;
-
-our $VERSION   = '0.13';
+our $VERSION   = '0.14';
 our $AUTHORITY = 'cpan:STEVAN';
 
-our @ISA; BEGIN { @ISA = ('UNIVERSAL::Object::Immutable') }
+use parent 'UNIVERSAL::Object::Immutable';
+
 our %HAS; BEGIN {
     %HAS = (
         original => sub { die '`original` is required' },
@@ -91,7 +90,7 @@ MOP::Method::Attribute - The Method Attribute object
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
@@ -114,7 +113,7 @@ Stevan Little <stevan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Stevan Little.
+This software is copyright (c) 2017, 2018 by Stevan Little.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
